==> piwigo-2.7.4.zip: piwigo/language/af_ZA/upgrade.lang.php <==
<?php
// +-----------------------------------------------------------------------+
// | Piwigo - a PHP based photo gallery                                    |
// +-----------------------------------------------------------------------+
// | Copyright(C) 2008-2014 Piwigo Team                  http://piwigo.org |
// | Copyright(C) 2003-2008 PhpWebGallery Team    http://phpwebgallery.net |
// | Copyright(C) 2002-2003 Pierrick LE GALL   http://le-gall.net/pierrick |
// +-----------------------------------------------------------------------+
// | This program is free software; you can redistribute it and/or modify  |
// | it under the terms of the GNU General Public License as published by  |
// | the Free Software Foundation                                          |
// |                                                                       |
// | This program is distributed in the hope that it will be useful, but   |
// | WITHOUT ANY WARRANTY; without even the implied warranty of            |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      |
// | General Public License for more details.                              |
// |                                                                       |
// | You should have received a copy of the GNU General Public License     |
// | along with this program; if not, write to the Free Software           |
// | Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, |
// | USA.                                                                  |
// +-----------------------------------------------------------------------+

$lang['Upgrade'] = "Upgrade";
$lang['Upgrade'] = "Opgradering";
$lang['This page proposes to upgrade your database corresponding to your old version of Piwigo to the current version. The upgrade assistant thinks you are currently running a <strong>release %s</strong> (or equivalent).'] = "Hierdie blad se doel is om die Piwigo databasis van 'n ou na nuwer weergawe te opgradeer. Die opgraderingassistent dink jy gebruik tans <strong>weergawe %s</strong> (of ekwivalent).";
$lang['Upgrade from version %s to %s'] = "Opgradeer van weergawe %s na %s";
$lang['Statistics'] = "Statistiek";
$lang['total upgrade time'] = "totale opgraderingstyd";
$lang['total SQL time'] = "totale SQL tyd";
$lang['SQL queries'] = "SQL navrae";
$lang['Upgrade informations'] = "Opgraderingsinligting";
$lang['Perform a maintenance check in [Administration>Tools>Maintenance] if you encounter any problem.'] = "Doen 'n instandhoudingsondersoek by [Administrasie>Werktuie>Instandhouding] indien jy enige probleme ondervind.";
$lang['As a precaution, following plugins have been deactivated. You must check for plugins upgrade before reactiving them:'] = "As voorsorg is die volgende invoegings gedeaktiveer. Voor heraktivering moet jy eers vir opgraderings soek:";
$lang['Only administrator can run upgrade: please sign in below.'] = "Net die administrateur kan opgraderings doen: teken hier onder aan.";
$lang['You do not have access rights to run upgrade'] = "Jy het nie toegangsregte op 'n opgradering te doen nie";
$lang['All sub-albums of private albums become private'] = "Alle onderalbums van privaat albums word ook privaat";
$lang['User permissions and group permissions have been erased'] = "Gebruiker en groepregte is uitgevee";
$lang['Only thumbnails prefix and webmaster mail address have been saved from previous configuration'] = "Slegs duimnaels en webmeester se pos adres is uit die vorige opstelling behou";
$lang['In <i>%s</i>, before <b>?></b>, insert:'] = 'In <i>%s</i>, voor <b>?></b>, voeg in:';
$lang['As a precaution, following themes have been deactivated. You must check for themes upgrade before reactiving them:'] = 'As voorsorg is die volgende temas gedeaktiveer. Voor heraktivering moet jy eers vir opgraderings soek:';
?>

==> piwigo-16.0.0.zip: piwigo/language/af_ZA/upgrade.lang.php <==
<?php
// +-----------------------------------------------------------------------+
// | This file is part of Piwigo.                                          |
// |                                                                       |
// | For copyright and license information, please view the COPYING.txt    |
// | file that was distributed with this source code.                      |
// +-----------------------------------------------------------------------+

$lang['Upgrade'] = "Upgrade";
$lang['Upgrade'] = "Opgradering";
$lang['This page proposes to upgrade your database corresponding to your old version of Piwigo to the current version. The upgrade assistant thinks you are currently running a <strong>release %s</strong> (or equivalent).'] = "Hierdie blad se doel is om die Piwigo databasis van 'n ou na nuwer weergawe te opgradeer. Die opgraderingassistent dink jy gebruik tans <strong>weergawe %s</strong> (of ekwivalent).";
$lang['Upgrade from version %s to %s'] = "Opgradeer van weergawe %s na %s";
$lang['Statistics'] = "Statistiek";
$lang['total upgrade time'] = "totale opgraderingstyd";
$lang['total SQL time'] = "totale SQL tyd";
$lang['SQL queries'] = "SQL navrae";
$lang['Upgrade informations'] = "Opgraderingsinligting";
$lang['Perform a maintenance check in [Administration>Tools>Maintenance] if you encounter any problem.'] = "Doen 'n instandhoudingsondersoek by [Administrasie>Werktuie>Instandhouding] indien jy enige probleme ondervind.";
$lang['As a precaution, following plugins have been deactivated. You must check for plugins upgrade before reactiving them:'] = "As voorsorg is die volgende invoegings gedeaktiveer. Voor heraktivering moet jy eers vir opgraderings soek:";
$lang['Only administrator can run upgrade: please sign in below.'] = "Net die administrateur kan opgraderings doen: teken hier onder aan.";
$lang['You do not have access rights to run upgrade'] = "Jy het nie toegangsregte op 'n opgradering te doen nie";
$lang['All sub-albums of private albums become private'] = "Alle onderalbums van privaat albums word ook privaat";
$lang['User permissions and group permissions have been erased'] = "Gebruiker en groepregte is uitgevee";
$lang['Only thumbnails prefix and webmaster mail address have been saved from previous configuration'] = "Slegs duimnaels en webmeester se pos adres is uit die vorige opstelling behou";
$lang['In <i>%s</i>, before <b>?></b>, insert:'] = 'In <i>%s</i>, voor <b>?></b>, voeg in:';
$lang['As a precaution, following themes have been deactivated. You must check for themes upgrade before reactiving them:'] = 'As voorsorg is die volgende temas gedeaktiveer. Voor heraktivering moet jy eers vir opgraderings soek:';
?>
